from setuptools import setup

setup(name='py_distributions_dsnd',
      version='0.2',
      description='Gaussian and Binomial distributions',
      packages=['py_distributions_dsnd'],
      author = 'Ayushi Mittal',
      author_email = '',
      zip_safe=False)
